@@ -1,14 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importkmailautocorrection.h"
 
+#include "pimcommon_debug.h"
 #include <QFile>
 #include <QXmlStreamReader>
-#include "pimcommon_debug.h"
 using namespace PimCommon;
 
 ImportKMailAutocorrection::ImportKMailAutocorrection(QWidget *parent)
@@ -16,9 +16,7 @@ ImportKMailAutocorrection::ImportKMailAutocorrection(QWidget *parent)
 {
 }
 
-ImportKMailAutocorrection::~ImportKMailAutocorrection()
-{
-}
+ImportKMailAutocorrection::~ImportKMailAutocorrection() = default;
 
 bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute loadAttribute)
 {
@@ -31,10 +29,19 @@ bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute lo
     mMinFindStringLenght = 0;
     if (xml.readNextStartElement()) {
         while (xml.readNextStartElement()) {
-            if (xml.name() == QLatin1String("UpperCaseExceptions")) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            const QStringRef xmlName = xml.name();
+#else
+            const QStringView xmlName = xml.name();
+#endif
+            if (xmlName == QLatin1String("UpperCaseExceptions")) {
                 if (loadAttribute == All) {
                     while (xml.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                         const QStringRef tagname = xml.name();
+#else
+                        const QStringView tagname = xml.name();
+#endif
                         if (tagname == QLatin1String("word")) {
                             if (xml.attributes().hasAttribute(QStringLiteral("exception"))) {
                                 const QString exception = xml.attributes().value(QStringLiteral("exception")).toString();
@@ -46,10 +53,14 @@ bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute lo
                 } else {
                     xml.skipCurrentElement();
                 }
-            } else if (xml.name() == QLatin1String("TwoUpperLetterExceptions")) {
+            } else if (xmlName == QLatin1String("TwoUpperLetterExceptions")) {
                 if (loadAttribute == All) {
                     while (xml.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                         const QStringRef tagname = xml.name();
+#else
+                        const QStringView tagname = xml.name();
+#endif
                         if (tagname == QLatin1String("word")) {
                             if (xml.attributes().hasAttribute(QStringLiteral("exception"))) {
                                 const QString exception = xml.attributes().value(QStringLiteral("exception")).toString();
@@ -63,10 +74,14 @@ bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute lo
                 } else {
                     xml.skipCurrentElement();
                 }
-            } else if (xml.name() == QLatin1String("DoubleQuote")) {
+            } else if (xmlName == QLatin1String("DoubleQuote")) {
                 if (loadAttribute == All) {
                     if (xml.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                         const QStringRef tagname = xml.name();
+#else
+                        const QStringView tagname = xml.name();
+#endif
                         if (tagname == QLatin1String("doublequote")) {
                             mTypographicDoubleQuotes.begin = xml.attributes().value(QStringLiteral("begin")).toString().at(0);
                             mTypographicDoubleQuotes.end = xml.attributes().value(QStringLiteral("end")).toString().at(0);
@@ -74,29 +89,45 @@ bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute lo
                         } else {
                             xml.skipCurrentElement();
                         }
+                        xml.skipCurrentElement();
                     }
                 } else {
                     xml.skipCurrentElement();
                 }
-            } else if (xml.name() == QLatin1String("SimpleQuote")) {
+            } else if (xmlName == QLatin1String("SimpleQuote")) {
                 if (loadAttribute == All) {
                     if (xml.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                         const QStringRef tagname = xml.name();
+#else
+                        const QStringView tagname = xml.name();
+#endif
                         if (tagname == QLatin1String("simplequote")) {
-                            mTypographicSingleQuotes.begin = xml.attributes().value(QStringLiteral("begin")).toString().at(0);
-                            mTypographicSingleQuotes.end = xml.attributes().value(QStringLiteral("end")).toString().at(0);
+                            const QString simpleQuoteBegin = xml.attributes().value(QStringLiteral("begin")).toString();
+                            if (!simpleQuoteBegin.isEmpty()) { // crash when we have old data with bug.
+                                mTypographicSingleQuotes.begin = simpleQuoteBegin.at(0);
+                            }
+                            const QString simpleQuoteEnd = xml.attributes().value(QStringLiteral("end")).toString();
+                            if (!simpleQuoteEnd.isEmpty()) { // crash when we have old data with bug.
+                                mTypographicSingleQuotes.end = simpleQuoteEnd.at(0);
+                            }
                             xml.skipCurrentElement();
                         } else {
                             xml.skipCurrentElement();
                         }
+                        xml.skipCurrentElement();
                     }
                 } else {
                     xml.skipCurrentElement();
                 }
-            } else if (xml.name() == QLatin1String("SuperScript")) {
+            } else if (xmlName == QLatin1String("SuperScript")) {
                 if (loadAttribute == All || loadAttribute == SuperScript) {
                     while (xml.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                         const QStringRef tagname = xml.name();
+#else
+                        const QStringView tagname = xml.name();
+#endif
                         if (tagname == QLatin1String("item")) {
                             const QString find = xml.attributes().value(QStringLiteral("find")).toString();
                             const QString super = xml.attributes().value(QStringLiteral("super")).toString();
@@ -109,10 +140,14 @@ bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute lo
                 } else {
                     xml.skipCurrentElement();
                 }
-            } else if (xml.name() == QLatin1String("items")) {
+            } else if (xmlName == QLatin1String("items")) {
                 if (loadAttribute == All) {
                     while (xml.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                         const QStringRef tagname = xml.name();
+#else
+                        const QStringView tagname = xml.name();
+#endif
                         if (tagname == QLatin1String("item")) {
                             const QString find = xml.attributes().value(QStringLiteral("find")).toString();
                             const QString replace = xml.attributes().value(QStringLiteral("replace")).toString();
@@ -129,7 +164,7 @@ bool ImportKMailAutocorrection::import(const QString &fileName, LoadAttribute lo
                     xml.skipCurrentElement();
                 }
             } else {
-                //TODO verify
+                // TODO verify
                 xml.skipCurrentElement();
             }
         }
