@@ -10,6 +10,7 @@
 #include <QStringList>
 
 #include "pimcommon_export.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 namespace PimCommon
 {
 /**
@@ -46,4 +47,4 @@ private:
     bool mFolder = false;
 };
 }
-
+#endif
