@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -40,6 +40,4 @@ void PimCommonSettings::slotSyncNow()
     config()->sync();
 }
 
-PimCommonSettings::~PimCommonSettings()
-{
-}
+PimCommonSettings::~PimCommonSettings() = default;
