@@ -1,13 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
-#ifndef ACLMODIFYJOB_H
-#define ACLMODIFYJOB_H
+#pragma once
 
-#include <AkonadiCore/collection.h>
+#include <Akonadi/Collection>
 #include <KIMAP/Acl>
 #include <QObject>
 class KJob;
@@ -51,4 +50,3 @@ private:
     int mCurrentIndex = -1;
 };
 }
-#endif // ACLMODIFYJOB_H
