@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ using namespace PimCommon;
 class PimCommon::PluginInterfacePrivate
 {
 public:
-    PluginInterfacePrivate()
-    {
-    }
+    PluginInterfacePrivate() = default;
 
     QString mPluginName;
     QString mPluginDirectory;
